@@ -10,10 +10,12 @@
 # pylint: disable=import-error
 # pylint: disable=pointless-string-statement
 # pylint: disable=invalid-name
+# pylint: disable=unused-import
+# flake8: noqa: F401
 
 """This files includes the python code example in dogsvscats.rst."""
 
-"""Authorize a Client Object"""
+"""Authorize a Client Instance"""
 from tensorbay import GAS
 
 ACCESS_KEY = "Accesskey-*****"
@@ -21,44 +23,40 @@ gas = GAS(ACCESS_KEY)
 """"""
 
 """Create Dataset"""
-gas.create_dataset("Dogs vs Cats")
+gas.create_dataset("DogsVsCats")
 """"""
 
-"""List Dataset Names"""
-list(gas.list_dataset_names())
+"""Organize Dataset / regular import"""
+from tensorbay.dataset import Data, Dataset
+from tensorbay.label import Classification
+
 """"""
 
+"""Organize dataset / import dataloader"""
 from tensorbay.opendataset import DogsVsCats
 
 dataset = DogsVsCats("path/to/dataset/directory")
+""""""
 
 """Upload Dataset"""
-# dataset is the one you initialized in "Organize Dataset" section
-dataset_client = gas.upload_dataset(dataset, jobs=8, skip_uploaded_files=False)
-dataset_client.commit("Dogs vs Cats")
+dataset_client = gas.upload_dataset(dataset)
+dataset_client.commit("initial commit")
 """"""
 
 """Read Dataset / get dataset"""
-dataset_client = gas.get_dataset("Dogs vs Cats")
+dataset = Dataset("DogsVsCats", gas)
 """"""
 
 """Read Dataset / list segment names"""
-list(dataset_client.list_segment_names())
-""""""
-
-"""Read Dataset Class / get a segment"""
-train_segment = dataset.get_segment_by_name("train")
-first_segment = dataset[0]
+dataset.keys()
 """"""
 
 """Read Dataset / get segment"""
-from tensorbay.dataset import Segment
-
-train_segment = Segment("train", dataset_client)
+segment = dataset["train"]
 """"""
 
 """Read Dataset / get data"""
-data = train_segment[0]
+data = segment[0]
 """"""
 
 """Read Dataset / get label"""
@@ -66,5 +64,5 @@ category = data.label.classification.category
 """"""
 
 """Delete Dataset"""
-gas.delete_dataset("Dogs vs Cats")
+gas.delete_dataset("DogsVsCats")
 """"""
