@@ -10,6 +10,8 @@
 # pylint: disable=import-error
 # pylint: disable=pointless-string-statement
 # pylint: disable=invalid-name
+# pylint: disable=unused-import
+# flake8: noqa: F401
 
 """This file includes the python code of LeedsSportsPose.rst."""
 
@@ -24,32 +26,34 @@ gas = GAS(ACCESS_KEY)
 gas.create_dataset("LeedsSportsPose")
 """"""
 
-"""List Dataset Names"""
-gas.list_dataset_names()
+"""Organize Dataset / regular import"""
+from tensorbay.dataset import Data, Dataset
+from tensorbay.geometry import Keypoint2D
+from tensorbay.label import LabeledKeypoints2D
+
 """"""
 
+"""Organize dataset / import dataloader"""
 from tensorbay.opendataset import LeedsSportsPose
 
 dataset = LeedsSportsPose("path/to/dataset/directory")
+""""""
 
 """Upload Dataset"""
-# dataset is the one you initialized in "Organize Dataset" section
-dataset_client = gas.upload_dataset(dataset, jobs=8, skip_uploaded_files=False)
+dataset_client = gas.upload_dataset(dataset)
 dataset_client.commit("initial commit")
 """"""
 
 """Read Dataset / get dataset"""
-dataset_client = gas.get_dataset("LeedsSportsPose")
+dataset = Dataset("LeedsSportsPose", gas)
 """"""
 
 """Read Dataset / get segment"""
-from tensorbay.dataset import Segment
-
-default_segment = Segment("", dataset_client)
+segment = dataset[0]
 """"""
 
 """Read Dataset / get data"""
-data = default_segment[0]
+data = segment[0]
 """"""
 
 """Read Dataset / get label"""
