@@ -10,6 +10,8 @@
 # pylint: disable=import-error
 # pylint: disable=pointless-string-statement
 # pylint: disable=invalid-name
+# pylint: disable=unused-import
+# flake8: noqa: F401
 
 """This file includes the python code of THCHS.rst and read_dataset_class.rst."""
 
@@ -24,38 +26,37 @@ gas = GAS(ACCESS_KEY)
 gas.create_dataset("THCHS-30")
 """"""
 
-"""List Dataset Names"""
-gas.list_dataset_names()
+"""Organize Dataset / regular import"""
+from tensorbay.dataset import Data, Dataset
+from tensorbay.label import LabeledSentence, SentenceSubcatalog, Word
+
 """"""
 
-
+"""Organize dataset / import dataloader"""
 from tensorbay.opendataset import THCHS30
 
 dataset = THCHS30("path/to/dataset/directory")
-
+""""""
 
 """Upload Dataset"""
-# dataset is the one you initialized in "Organize Dataset" section
-dataset_client = gas.upload_dataset(dataset, jobs=8, skip_uploaded_files=False)
+dataset_client = gas.upload_dataset(dataset)
 dataset_client.commit("initial commit")
 """"""
 
 """Read Dataset / get dataset"""
-dataset_client = gas.get_dataset("THCHS-30")
+dataset = Dataset("THCHS-30", gas)
 """"""
 
 """Read Dataset / list segment names"""
-dataset_client.list_segment_names()
+dataset.keys()
 """"""
 
 """Read Dataset / get segment"""
-from tensorbay.dataset import Segment
-
-dev_segment = Segment("dev", dataset_client)
+segment = dataset["dev"]
 """"""
 
 """Read Dataset / get data"""
-data = dev_segment[0]
+data = segment[0]
 """"""
 
 """Read Dataset / get label"""
