@@ -5,14 +5,24 @@
 
 """Client module."""
 
-from .exceptions import GASDatasetError, GASPathError, GASSegmentError
+from .exceptions import (
+    GASDatasetError,
+    GASDatasetTypeError,
+    GASException,
+    GASPathError,
+    GASResponseError,
+    GASSegmentError,
+)
 from .gas import GAS
 from .requests import config
 
 __all__ = [
     "GAS",
     "GASDatasetError",
+    "GASDatasetTypeError",
+    "GASException",
     "GASPathError",
+    "GASResponseError",
     "GASSegmentError",
     "config",
 ]
