@@ -13,16 +13,14 @@ AccessKey is required when operating with dataset.
 
 """
 
-import sys
 from typing import Any, Dict, Generator, Optional, Type, Union, overload
 
 from typing_extensions import Literal
 
 from ..dataset import Dataset, FusionDataset
-from ..exception import DatasetTypeError
+from ..exception import DatasetTypeError, ResourceNotExistError
 from ..utility import KwargsDeprecated
 from .dataset import DatasetClient, FusionDatasetClient
-from .exceptions import GASDatasetError
 from .requests import Client, PagingList, Tqdm
 
 DatasetClientType = Union[DatasetClient, FusionDatasetClient]
@@ -74,17 +72,17 @@ class GAS:
             The dict of dataset information.
 
         Raises:
-            GASDatasetError: When the required dataset does not exist.
+            ResourceNotExistError: When the required dataset does not exist.
 
         """
         if not name:
-            raise GASDatasetError(name)
+            raise ResourceNotExistError(resource="dataset", identification=name)
 
         try:
             response = self._list_datasets(name=name)
             info = response["datasets"][0]
         except IndexError as error:
-            raise GASDatasetError(name) from error
+            raise ResourceNotExistError(resource="dataset", identification=name) from error
 
         return info  # type: ignore[no-any-return]
 
@@ -131,8 +129,8 @@ class GAS:
             The auth storage config with the given name.
 
         Raises:
-            TypeError: When the required auth storage config does not exist
-                 or the given auth storage config is illegal.
+            TypeError: When the given auth storage config is illegal.
+            ResourceNotExistError: When the required auth storage config does not exist.
 
         """
         if not name:
@@ -141,7 +139,9 @@ class GAS:
         try:
             config = next(self._generate_auth_storage_configs(name))
         except StopIteration as error:
-            raise TypeError(f"The auth storage config: {name} does not exist.") from error
+            raise ResourceNotExistError(
+                resource="auth storage config", identification=name
+            ) from error
 
         return config
 
@@ -303,14 +303,16 @@ class GAS:
             The PagingList of all TensorBay dataset names.
 
         """
-        start = kwargs.get("start", 0)
-        stop = kwargs.get("stop", sys.maxsize)
-
-        return PagingList(
+        start = kwargs.get("start")
+        stop = kwargs.get("stop")
+        paging_list = PagingList(
             lambda offset, limit: self._generate_dataset_names(None, False, offset, limit),
             128,
-            slice(start, stop),
         )
+        if start is not None or stop is not None:
+            return paging_list[start:stop]
+
+        return paging_list
 
     def rename_dataset(self, name: str, new_name: str) -> None:
         """Rename a TensorBay Dataset with given name.
