@@ -24,22 +24,21 @@ for more information.
 """
 
 import os
-import sys
-import threading
 import time
 from copy import deepcopy
 from itertools import islice
-from typing import TYPE_CHECKING, Any, Dict, Iterable, Iterator, Optional, Tuple, Union
+from typing import TYPE_CHECKING, Any, Dict, Generator, Iterable, Optional, Tuple, Union
 
 import filetype
 from requests_toolbelt import MultipartEncoder
 from ulid import from_timestamp
 
 from ..dataset import Data, Frame, RemoteData
+from ..exception import FrameError, InvalidParamsError, ResponseSystemError
 from ..sensor.sensor import Sensor, Sensors
+from ..utility import KwargsDeprecated, locked
 from .commit_status import CommitStatus
-from .exceptions import GASException, GASPathError
-from .requests import default_config, paging_range
+from .requests import PagingList, config
 
 if TYPE_CHECKING:
     from .dataset import DatasetClient, FusionDatasetClient
@@ -61,6 +60,10 @@ class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
         name: Segment name.
         dataset_client: The dataset client.
 
+    Attributes:
+        name: Segment name.
+        status: The status of the dataset client.
+
     """
 
     _EXPIRED_IN_SECOND = 240
@@ -75,7 +78,6 @@ class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
         self._status = dataset_client.status
         self._client = dataset_client._client  # pylint: disable=protected-access
         self._permission: Dict[str, Any] = {"expireAt": 0}
-        self._permission_lock = threading.Lock()
 
     def _get_url(self, remote_path: str) -> str:
         """Get URL of a specific remote path.
@@ -93,57 +95,40 @@ class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
         }
         params.update(self._status.get_status_info())
 
+        if config.is_internal:
+            params["isInternal"] = True
+
         response = self._client.open_api_do("GET", "data/urls", self._dataset_id, params=params)
         return response.json()["urls"][0]["url"]  # type: ignore[no-any-return]
 
-    def _list_labels(
-        self, *, start: int = 0, stop: int = sys.maxsize, page_size: int = 128
-    ) -> Iterator[Dict[str, Any]]:
-        """List labels of the segment in a certain commit.
-
-        Arguments:
-            start: The index to start.
-            stop: The index to stop.
-            page_size: The page size for the listed labels.
-
-        Yields:
-            Labels in a segment in a certain commit.
-
-        """
-        params: Dict[str, Any] = {"segmentName": self._name}
+    def _list_labels(self, offset: int = 0, limit: int = 128) -> Dict[str, Any]:
+        params: Dict[str, Any] = {
+            "segmentName": self._name,
+            "offset": offset,
+            "limit": limit,
+        }
         params.update(self._status.get_status_info())
 
-        for params["offset"], params["limit"] in paging_range(start, stop, page_size):
-            response = self._client.open_api_do(
-                "GET", "labels", self._dataset_id, params=params
-            ).json()
-            yield from response["labels"]
-            if response["recordSize"] + response["offset"] >= response["totalCount"]:
-                break
+        response = self._client.open_api_do("GET", "labels", self._dataset_id, params=params)
+        return response.json()  # type: ignore[no-any-return]
+
+    @locked
+    def _request_upload_permission(self) -> None:
+        params: Dict[str, Any] = {"expired": self._EXPIRED_IN_SECOND, "segmentName": self._name}
+        params.update(self._status.get_status_info())
+
+        if config.is_internal:
+            params["isInternal"] = True
+
+        self._permission = self._client.open_api_do(
+            "GET", "policies", self._dataset_id, params=params
+        ).json()
 
     def _get_upload_permission(self) -> Dict[str, Any]:
-        with self._permission_lock:
-            if int(time.time()) >= self._permission["expireAt"]:
-                params: Dict[str, Any] = {
-                    "expired": self._EXPIRED_IN_SECOND,
-                    "segmentName": self._name,
-                }
-                params.update(self._status.get_status_info())
+        if int(time.time()) >= self._permission["expireAt"]:
+            self._request_upload_permission()
 
-                self._permission = self._client.open_api_do(
-                    "GET", "policies", self._dataset_id, params=params
-                ).json()
-
-                if default_config.is_intern:
-                    urlsplit = self._permission["extra"]["host"].rsplit(".", 2)
-                    urlsplit[0] += "-internal"
-                    self._permission["extra"]["host"] = ".".join(urlsplit)
-
-            return deepcopy(self._permission)
-
-    def _clear_upload_permission(self) -> None:
-        with self._permission_lock:
-            self._permission = {"expireAt": 0}
+        return deepcopy(self._permission)
 
     def _post_multipart_formdata(
         self,
@@ -179,8 +164,13 @@ class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
             response_headers = self._client.do("PUT", url, data=fp, headers=request_headers).headers
             return response_headers["x-ms-version-id"], response_headers["ETag"].strip('"')
 
-    def _synchronize_upload_info(
-        self, key: str, version_id: str, etag: str, frame_info: Optional[Dict[str, Any]] = None
+    def _synchronize_upload_info(  # pylint: disable=too-many-arguments
+        self,
+        key: str,
+        version_id: str,
+        etag: str,
+        frame_info: Optional[Dict[str, Any]] = None,
+        skip_uploaded_files: bool = False,
     ) -> None:
         put_data: Dict[str, Any] = {
             "key": key,
@@ -192,7 +182,11 @@ class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
         if frame_info:
             put_data.update(frame_info)
 
-        self._client.open_api_do("PUT", "callback", self._dataset_id, json=put_data)
+        try:
+            self._client.open_api_do("PUT", "callback", self._dataset_id, json=put_data)
+        except ResponseSystemError:
+            if not skip_uploaded_files:
+                raise
 
     def _upload_label(self, data: Data) -> None:
         label = data.label.dumps()
@@ -266,30 +260,30 @@ class SegmentClient(SegmentClientBase):
     def __init__(self, name: str, data_client: "DatasetClient") -> None:
         super().__init__(name, data_client)
 
-    def _list_data(
-        self, *, start: int = 0, stop: int = sys.maxsize, page_size: int = 128
-    ) -> Iterator[Dict[str, Any]]:
-        """List data in a segment in a certain commit.
-
-        Arguments:
-            start: The index to start.
-            stop: The index to stop.
-            page_size: The page size for listed data.
-
-        Yields:
-            Data in a segment client.
-
-        """
-        params: Dict[str, Any] = {"segmentName": self._name}
+    def _generate_data_paths(self, offset: int = 0, limit: int = 128) -> Generator[str, None, int]:
+        params: Dict[str, Any] = {
+            "segmentName": self._name,
+            "offset": offset,
+            "limit": limit,
+        }
         params.update(self._status.get_status_info())
 
-        for params["offset"], params["limit"] in paging_range(start, stop, page_size):
-            response = self._client.open_api_do(
-                "GET", "data", self._dataset_id, params=params
-            ).json()
-            yield from response["data"]
-            if response["recordSize"] + response["offset"] >= response["totalCount"]:
-                break
+        response = self._client.open_api_do("GET", "data", self._dataset_id, params=params).json()
+
+        for item in response["data"]:
+            yield item["remotePath"]
+
+        return response["totalCount"]  # type: ignore[no-any-return]
+
+    def _generate_data(self, offset: int = 0, limit: int = 128) -> Generator[RemoteData, None, int]:
+        response = self._list_labels(offset, limit)
+
+        for item in response["labels"]:
+            data = RemoteData.loads(item)
+            data._url_getter = self._get_url  # pylint: disable=protected-access
+            yield data
+
+        return response["totalCount"]  # type: ignore[no-any-return]
 
     def upload_file(self, local_path: str, target_remote_path: str = "") -> None:
         """Upload data with local path to the draft.
@@ -299,8 +293,7 @@ class SegmentClient(SegmentClientBase):
             target_remote_path: The path to save the data in segment client.
 
         Raises:
-            GASPathError: When target_remote_path does not follow linux style.
-            GASException: When uploading data failed.
+            InvalidParamsError: When target_remote_path does not follow linux style.
 
         """
         self._status.check_authority_for_draft()
@@ -309,34 +302,29 @@ class SegmentClient(SegmentClientBase):
             target_remote_path = os.path.basename(local_path)
 
         if "\\" in target_remote_path:
-            raise GASPathError(target_remote_path)
+            raise InvalidParamsError(param_name="path", param_value=target_remote_path)
 
         permission = self._get_upload_permission()
         post_data = permission["result"]
         post_data["key"] = permission["extra"]["objectPrefix"] + target_remote_path
 
-        try:
-            backend_type = permission["extra"]["backendType"]
-            if backend_type == "azure":
-                url = (
-                    f'{permission["extra"]["host"]}{permission["extra"]["objectPrefix"]}'
-                    f'{target_remote_path}?{permission["result"]["token"]}'
-                )
+        backend_type = permission["extra"]["backendType"]
+        if backend_type == "azure":
+            url = (
+                f'{permission["extra"]["host"]}{permission["extra"]["objectPrefix"]}'
+                f'{target_remote_path}?{permission["result"]["token"]}'
+            )
 
-                version_id, etag = self._put_binary_file_to_azure(url, local_path, post_data)
-            else:
-                version_id, etag = self._post_multipart_formdata(
-                    permission["extra"]["host"],
-                    local_path,
-                    target_remote_path,
-                    post_data,
-                )
+            version_id, etag = self._put_binary_file_to_azure(url, local_path, post_data)
+        else:
+            version_id, etag = self._post_multipart_formdata(
+                permission["extra"]["host"],
+                local_path,
+                target_remote_path,
+                post_data,
+            )
 
-            self._synchronize_upload_info(post_data["key"], version_id, etag)
-
-        except GASException:
-            self._clear_upload_permission()
-            raise
+        self._synchronize_upload_info(post_data["key"], version_id, etag)
 
     def upload_label(self, data: Data) -> None:
         """Upload label with Data object to the draft.
@@ -361,34 +349,55 @@ class SegmentClient(SegmentClientBase):
         self.upload_file(data.path, data.target_remote_path)
         self._upload_label(data)
 
-    def list_data_paths(self, *, start: int = 0, stop: int = sys.maxsize) -> Iterator[str]:
+    @KwargsDeprecated(
+        ("start", "stop"),
+        since="1.3.0",
+        removed_in="1.5.0",
+        substitute="PagingList[start:stop]",
+    )
+    def list_data_paths(self, **kwargs: int) -> PagingList[str]:
         """List required data path in a segment in a certain commit.
 
         Arguments:
-            start: The index to start.
-            stop: The index to end.
+            kwargs: For deprecated keyword arguments: "start" and "stop".
 
-        Yields:
-            Required data paths.
+        Returns:
+            The PagingList of data paths.
 
         """
-        yield from (item["remotePath"] for item in self._list_data(start=start, stop=stop))
+        start = kwargs.get("start")
+        stop = kwargs.get("stop")
 
-    def list_data(self, *, start: int = 0, stop: int = sys.maxsize) -> Iterator[RemoteData]:
+        paging_list = PagingList(self._generate_data_paths, 128)
+        if start is not None or stop is not None:
+            return paging_list[start:stop]
+
+        return paging_list
+
+    @KwargsDeprecated(
+        ("start", "stop"),
+        since="1.3.0",
+        removed_in="1.5.0",
+        substitute="PagingList[start:stop]",
+    )
+    def list_data(self, **kwargs: int) -> PagingList[RemoteData]:
         """List required Data object in a dataset segment.
 
         Arguments:
-            start: The index to start.
-            stop: The index to stop.
+            kwargs: For deprecated keyword arguments: "start" and "stop".
 
-        Yields:
-            Required Data object.
+        Returns:
+            The PagingList of :class:`~tensorbay.dataset.data.RemoteData`.
 
         """
-        for data_content in self._list_labels(start=start, stop=stop):
-            data = RemoteData.loads(data_content)
-            data._url_getter = self._get_url  # pylint: disable=protected-access
-            yield data
+        start = kwargs.get("start")
+        stop = kwargs.get("stop")
+
+        paging_list = PagingList(self._generate_data, 128)
+        if start is not None or stop is not None:
+            return paging_list[start:stop]
+
+        return paging_list
 
 
 class FusionSegmentClient(SegmentClientBase):
@@ -409,30 +418,17 @@ class FusionSegmentClient(SegmentClientBase):
     def __init__(self, name: str, data_client: "FusionDatasetClient") -> None:
         super().__init__(name, data_client)
 
-    def _list_frames(
-        self, *, start: int = 0, stop: int = sys.maxsize, page_size: int = 128
-    ) -> Iterator[Dict[str, Any]]:
-        """List all frames in a segment in a certain commit.
+    def _generate_frames(self, offset: int = 0, limit: int = 128) -> Generator[Frame, None, int]:
+        response = self._list_labels(offset, limit)
 
-        Arguments:
-            start: The index to start.
-            stop: The index to stop.
-            page_size: The page size for listed frames.
+        for item in response["labels"]:
+            frame = Frame.loads(item)
+            for data in frame.values():  # pylint: disable=no-member # pylint issue: #3131
+                # pylint: disable=protected-access
+                data._url_getter = self._get_url  # type: ignore[union-attr]
+            yield frame
 
-        Yields:
-             Required frames.
-
-        """
-        params: Dict[str, Any] = {"segmentName": self._name}
-        params.update(self._status.get_status_info())
-
-        for params["offset"], params["limit"] in paging_range(start, stop, page_size):
-            response = self._client.open_api_do(
-                "GET", "data", self._dataset_id, params=params
-            ).json()
-            yield from response["data"]
-            if response["recordSize"] + response["offset"] >= response["totalCount"]:
-                break
+        return response["totalCount"]  # type: ignore[no-any-return]
 
     def get_sensors(self) -> Sensors:
         """Return the sensors in a fusion segment client.
@@ -479,17 +475,19 @@ class FusionSegmentClient(SegmentClientBase):
 
         self._client.open_api_do("DELETE", "sensors", self._dataset_id, json=delete_data)
 
-    def upload_frame(self, frame: Frame, timestamp: Optional[float] = None) -> None:
+    def upload_frame(  # pylint: disable=too-many-locals
+        self, frame: Frame, timestamp: Optional[float] = None, skip_uploaded_files: bool = False
+    ) -> None:
         """Upload frame to the draft.
 
         Arguments:
             frame: The :class:`~tensorbay.dataset.frame.Frame` to upload.
             timestamp: The mark to sort frames, supporting timestamp and float.
+            skip_uploaded_files: Set it to True to skip the uploaded files.
 
         Raises:
-            GASPathError: When remote_path does not follow linux style.
-            GASException: When uploading frame failed.
-            TypeError: When frame id conflicts。                                `
+            FrameError: When lacking frame id or frame id conflicts.
+            InvalidParamsError: When remote_path does not follow linux style.
 
         """
         self._status.check_authority_for_draft()
@@ -498,14 +496,14 @@ class FusionSegmentClient(SegmentClientBase):
             try:
                 frame_id = frame.frame_id
             except AttributeError as error:
-                raise TypeError(
+                raise FrameError(
                     "Lack frame id, please add frame id in frame or "
                     "give timestamp to the function!"
                 ) from error
         elif not hasattr(frame, "frame_id"):
             frame_id = from_timestamp(timestamp)
         else:
-            raise TypeError("Frame id conflicts, please do not give timestamp to the function!.")
+            raise FrameError("Frame id conflicts, please do not give timestamp to the function!.")
 
         for sensor_name, data in frame.items():
             if not isinstance(data, Data):
@@ -514,58 +512,63 @@ class FusionSegmentClient(SegmentClientBase):
             target_remote_path = data.target_remote_path
 
             if "\\" in target_remote_path:
-                raise GASPathError(target_remote_path)
+                raise InvalidParamsError(param_name="path", param_value=target_remote_path)
 
             permission = self._get_upload_permission()
             post_data = permission["result"]
             post_data["key"] = permission["extra"]["objectPrefix"] + target_remote_path
 
-            try:
-                backend_type = permission["extra"]["backendType"]
-                if backend_type == "azure":
-                    url = (
-                        f'{permission["extra"]["host"]}{permission["extra"]["objectPrefix"]}'
-                        f'{target_remote_path}?{permission["result"]["token"]}'
-                    )
+            backend_type = permission["extra"]["backendType"]
+            if backend_type == "azure":
+                url = (
+                    f'{permission["extra"]["host"]}{permission["extra"]["objectPrefix"]}'
+                    f'{target_remote_path}?{permission["result"]["token"]}'
+                )
 
-                    version_id, etag = self._put_binary_file_to_azure(url, data.path, post_data)
-                else:
-                    version_id, etag = self._post_multipart_formdata(
-                        permission["extra"]["host"],
-                        data.path,
-                        target_remote_path,
-                        post_data,
-                    )
+                version_id, etag = self._put_binary_file_to_azure(url, data.path, post_data)
+            else:
+                version_id, etag = self._post_multipart_formdata(
+                    permission["extra"]["host"],
+                    data.path,
+                    target_remote_path,
+                    post_data,
+                )
 
-                frame_info: Dict[str, Any] = {
-                    "segmentName": self._name,
-                    "sensorName": sensor_name,
-                    "frameId": str(frame_id),
-                }
-                if hasattr(data, "timestamp"):
-                    frame_info["timestamp"] = data.timestamp
+            frame_info: Dict[str, Any] = {
+                "segmentName": self._name,
+                "sensorName": sensor_name,
+                "frameId": str(frame_id),
+            }
+            if hasattr(data, "timestamp"):
+                frame_info["timestamp"] = data.timestamp
 
-                self._synchronize_upload_info(post_data["key"], version_id, etag, frame_info)
+            self._synchronize_upload_info(
+                post_data["key"], version_id, etag, frame_info, skip_uploaded_files
+            )
 
-            except GASException:
-                self._clear_upload_permission()
-                raise
             self._upload_label(data)
 
-    def list_frames(self, *, start: int = 0, stop: int = sys.maxsize) -> Iterator[Frame]:
+    @KwargsDeprecated(
+        ("start", "stop"),
+        since="1.3.0",
+        removed_in="1.5.0",
+        substitute="PagingList[start:stop]",
+    )
+    def list_frames(self, **kwargs: int) -> PagingList[Frame]:
         """List required frames in the segment in a certain commit.
 
         Arguments:
-            start: The index to start.
-            stop: The index to stop.
+            kwargs: For deprecated keyword arguments: "start" and "stop".
 
-        Yields:
-            Required :class:`~tensorbay.dataset.frame.Frame`.
+        Returns:
+            The PagingList of :class:`~tensorbay.dataset.frame.Frame`.
 
         """
-        for frame_content in self._list_labels(start=start, stop=stop):
-            frame = Frame.loads(frame_content)
-            for data in frame.values():  # pylint: disable=no-member # pylint issue: #3131
-                # pylint: disable=protected-access
-                data._url_getter = self._get_url  # type: ignore[union-attr]
-            yield frame
+        start = kwargs.get("start")
+        stop = kwargs.get("stop")
+
+        paging_list = PagingList(self._generate_frames, 128)
+        if start is not None or stop is not None:
+            return paging_list[start:stop]
+
+        return paging_list
