@@ -16,15 +16,19 @@ along with multiple :class:`~tensorbay.sensor.sensor.Sensors`.
 
 """
 
-from typing import TYPE_CHECKING, Any, Callable, List, Optional, TypeVar
+from typing import TYPE_CHECKING, Any, Callable, MutableSequence, Optional, Type, TypeVar
 
 from ..sensor import Sensors
 from ..utility import NameMixin, ReprType, UserMutableSequence
-from .data import DataBase
 from .frame import Frame
 
 if TYPE_CHECKING:
     from ..client.dataset import DatasetClient, FusionDatasetClient
+    from ..client.segment import FusionSegmentClient, SegmentClient
+    from .data import DataBase
+
+_S = TypeVar("_S", bound="Segment")
+_FS = TypeVar("_FS", bound="FusionSegment")
 
 
 class Segment(NameMixin, UserMutableSequence["DataBase._Type"]):
@@ -54,20 +58,36 @@ class Segment(NameMixin, UserMutableSequence["DataBase._Type"]):
 
     """
 
-    _T = TypeVar("_T", bound="Segment")
-
     _repr_type = ReprType.SEQUENCE
 
     def __init__(self, name: str = "", client: Optional["DatasetClient"] = None) -> None:
         super().__init__(name)
 
-        self._data: List[DataBase._Type]
         if client:
             self._client = client.get_segment(name)
-            self._data = list(self._client.list_data())
+            self._data = self._client.list_data()  # type: ignore[assignment]
+            self._repr_non_empty = True
         else:
             self._data = []
 
+    @classmethod
+    def _from_client(cls: Type[_S], client: "SegmentClient") -> _S:
+        """Init a Segment from :class:`~tensorbay.client.segment.SegmentClient`.
+
+        Arguments:
+            client: The :class:`~tensorbay.client.segment.SegmentClient`.
+
+        Returns:
+            The Segment of the input :class:`~tensorbay.client.segment.SegmentClient`.
+
+        """
+        # pylint: disable=protected-access
+        segment = cls(client.name)
+        segment._client = client
+        segment._data = client.list_data()  # type: ignore[assignment]
+        segment._repr_non_empty = True
+        return segment
+
     def sort(
         self,
         *,
@@ -85,8 +105,16 @@ class Segment(NameMixin, UserMutableSequence["DataBase._Type"]):
                 By default, the data within the segment is sorted by fileuri.
             reverse: The reverse flag can be set as True to sort in descending order.
 
+        Raises:
+            NotImplementedError: The sort method for segment init from client is not supported yet.
+
         """
-        self._data.sort(key=key, reverse=reverse)
+        try:
+            self._data.sort(key=key, reverse=reverse)  # type: ignore[attr-defined]
+        except AttributeError as error:
+            raise NotImplementedError(
+                "The sort method for segment init from client is not supported yet."
+            ) from error
 
 
 class FusionSegment(NameMixin, UserMutableSequence[Frame]):
@@ -122,20 +150,54 @@ class FusionSegment(NameMixin, UserMutableSequence[Frame]):
 
     """
 
-    _T = TypeVar("_T", bound="FusionSegment")
-
     _repr_type = ReprType.SEQUENCE
     _repr_attrs = ("sensors",)
     _repr_maxlevel = 2
 
     def __init__(self, name: str = "", client: Optional["FusionDatasetClient"] = None) -> None:
         super().__init__(name)
-        self.sensors = Sensors()
 
-        self._data: List[Frame]
+        self._data: MutableSequence[Frame]
         if client:
             self._client = client.get_segment(name)
-            self._data = list(self._client.list_frames())
-            self.sensors = self._client.get_sensors()
+            self._data = self._client.list_frames()
+            self._repr_non_empty = True
         else:
             self._data = []
+            self._sensors = Sensors()
+
+    @classmethod
+    def _from_client(cls: Type[_FS], client: "FusionSegmentClient") -> _FS:
+        """Init a FusionSegment from :class:`~tensorbay.client.segment.FusionSegmentClient`.
+
+        Arguments:
+            client: The :class:`~tensorbay.client.segment.FusionSegmentClient`.
+
+        Returns:
+            The FusionSegment of the input :class:`~tensorbay.client.segment.FusionSegmentClient`.
+
+        """
+        # pylint: disable=protected-access
+        segment: _FS = object.__new__(cls)
+        super(cls, segment).__init__(client.name)
+        segment._client = client
+        segment._data = client.list_frames()
+        segment._repr_non_empty = True
+        return segment
+
+    @property
+    def sensors(self) -> Sensors:
+        """Return the sensors of the fusion segment.
+
+        Returns:
+            The :class:`~tensorbay.sensor.sensor.Sensors` of the fusion dataset.
+
+        """
+        if not hasattr(self, "_sensors"):
+            self._sensors = self._client.get_sensors()
+
+        return self._sensors
+
+    @sensors.setter
+    def sensors(self, sensors: Sensors) -> None:
+        self._sensors = sensors
