@@ -9,7 +9,6 @@ from .box import Box2D, Box3D
 from .keypoint import Keypoint2D, Keypoints2D
 from .polygon import Polygon2D
 from .polyline import Polyline2D
-from .quaternion import Quaternion
 from .transform import Transform3D
 from .vector import Vector, Vector2D, Vector3D
 
@@ -20,7 +19,6 @@ __all__ = [
     "Keypoints2D",
     "Polygon2D",
     "Polyline2D",
-    "Quaternion",
     "Transform3D",
     "Vector",
     "Vector2D",
