@@ -8,10 +8,15 @@
 import pytest
 
 from tensorbay import __version__
-from tensorbay.client import GAS, GASSegmentError
+from tensorbay.client import GAS
 from tensorbay.client.struct import Draft
 from tensorbay.dataset import Data, Frame, FusionSegment, Segment
-from tensorbay.exception import CommitStatusError, ResponseError
+from tensorbay.exception import (
+    CommitStatusError,
+    NameConflictError,
+    ResourceNotExistError,
+    ResponseError,
+)
 from tensorbay.label import Catalog, Label
 from tensorbay.sensor import Sensor
 
@@ -185,7 +190,7 @@ class TestDatasetClient:
         assert tag.committer.date
 
         # Can not get a non-exist tag
-        with pytest.raises(TypeError):
+        with pytest.raises(ResourceNotExistError):
             dataset_client.get_tag("V2")
 
         dataset_client.create_draft("draft-2")
@@ -225,7 +230,7 @@ class TestDatasetClient:
 
         dataset_client.delete_tag("V1")
 
-        with pytest.raises(TypeError):
+        with pytest.raises(ResourceNotExistError):
             dataset_client.get_tag("V1")
 
         gas_client.delete_dataset(dataset_name)
@@ -248,7 +253,7 @@ class TestDatasetClient:
         assert branch.message == "commit-2"
         assert branch.committer.name
         assert branch.committer.date
-        with pytest.raises(TypeError):
+        with pytest.raises(ResourceNotExistError):
             dataset_client.get_branch("main1")
 
         gas_client.delete_dataset(dataset_name)
@@ -334,10 +339,10 @@ class TestDatasetClient:
         assert commit.committer.name
         assert commit.committer.date
 
-        with pytest.raises(TypeError):
+        with pytest.raises(ResourceNotExistError):
             dataset_client.get_commit("V2")
 
-        with pytest.raises(TypeError):
+        with pytest.raises(ResourceNotExistError):
             dataset_client.get_commit("main1")
 
         gas_client.delete_dataset(dataset_name)
@@ -394,7 +399,7 @@ class TestDatasetClient:
         dataset_client.checkout(revision=commit_1_id)
         assert dataset_client._status.commit_id == commit_1_id
         # The commit does not exist.
-        with pytest.raises(TypeError):
+        with pytest.raises(ResourceNotExistError):
             dataset_client.checkout(revision="123")
         assert dataset_client._status.commit_id == commit_1_id
         dataset_client.checkout(revision="V1")
@@ -404,7 +409,7 @@ class TestDatasetClient:
 
         dataset_client.create_draft("draft-3")
         # The draft does not exist.
-        with pytest.raises(TypeError):
+        with pytest.raises(ResourceNotExistError):
             dataset_client.checkout(draft_number=2)
         dataset_client.checkout(draft_number=3)
         assert dataset_client._status.draft_number == 3
@@ -445,7 +450,7 @@ class TestDatasetClient:
         dataset_client.create_draft("draft-1")
         segment_client = dataset_client.create_segment("segment")
         # Cannot create duplicated segment
-        with pytest.raises(TypeError):
+        with pytest.raises(NameConflictError):
             dataset_client.create_segment("segment")
         assert segment_client.status.is_draft
         assert segment_client.name == "segment"
@@ -520,7 +525,7 @@ class TestDatasetClient:
         dataset_client.get_or_create_segment("segment1")
 
         dataset_client.delete_segment("segment1")
-        with pytest.raises(GASSegmentError):
+        with pytest.raises(ResourceNotExistError):
             dataset_client.get_segment("segment1")
 
         gas_client.delete_dataset(dataset_name)
